@@ -25,7 +25,7 @@
 # OTHER DEALINGS IN THE SOFTWARE.
 from __future__ import unicode_literals
 
-__version__ = version = '0.6.1'
+__version__ = version = '0.6.2'
 
 import sys
 
@@ -40,3 +40,6 @@ SELF = sys.modules[__name__]
 
 for attr in [name.decode() for name in httpretty.METHODS] + ['register_uri', 'enable', 'disable', 'is_enabled', 'Response']:
     setattr(SELF, attr, getattr(httpretty, attr))
+
+def last_request():
+    return httpretty.last_request
