@@ -25,6 +25,7 @@
 # OTHER DEALINGS IN THE SOFTWARE.
 from __future__ import unicode_literals
 
+import re
 import inspect
 import socket
 import functools
@@ -142,7 +143,8 @@ class fakesock(object):
         debuglevel = 0
         _sent_data = []
 
-        def __init__(self, family, type, protocol=6):
+        def __init__(self, family=socket.AF_INET, type=socket.SOCK_STREAM,
+                     protocol=0):
             self.setsockopt(family, type, protocol)
             self.truesock = old_socket(family, type, protocol)
             self._closed = True
@@ -163,14 +165,14 @@ class fakesock(object):
                 ),
                 'subject': (
                     (
-                        ('organizationName', u'*.%s' % self._host),
+                        ('organizationName', '*.%s' % self._host),
                     ),
                     (
                         ('organizationalUnitName',
-                         u'Domain Control Validated'),
+                         'Domain Control Validated'),
                     ),
                     (
-                        ('commonName', u'*.%s' % self._host),
+                        ('commonName', '*.%s' % self._host),
                     ),
                 ),
             }
@@ -356,8 +358,10 @@ class Entry(BaseClass):
             self.callable_body = body
             self.body = None
             self.body_is_callable = True
-
-        self.body = body
+        elif isinstance(body, text_type):
+            self.body = utf8(body)
+        else:
+            self.body = body
 
         self.streaming = streaming
         if not streaming and not self.body_is_callable:
@@ -630,7 +634,7 @@ class URIMatcher(object):
 
 
 class httpretty(HttpBaseClass):
-    u"""The URI registration class"""
+    """The URI registration class"""
     _entries = {}
     latest_requests = []
 
@@ -660,16 +664,21 @@ class httpretty(HttpBaseClass):
                      status=200,
                      responses=None, **headers):
 
+        uri_is_string = isinstance(uri, basestring)
+
+        if uri_is_string and re.search(r'^\w+://[^/]+[.]\w{2,}$', uri):
+            uri += '/'
+
         if isinstance(responses, list) and len(responses) > 0:
             for response in responses:
                 response.uri = uri
                 response.method = method
             entries_for_this_uri = responses
         else:
-            headers['body'] = body
-            headers['adding_headers'] = adding_headers
-            headers['forcing_headers'] = forcing_headers
-            headers['status'] = status
+            headers[str('body')] = body
+            headers[str('adding_headers')] = adding_headers
+            headers[str('forcing_headers')] = forcing_headers
+            headers[str('status')] = status
 
             entries_for_this_uri = [
                 cls.Response(method=method, uri=uri, **headers),
@@ -683,17 +692,17 @@ class httpretty(HttpBaseClass):
         cls._entries[matcher] = entries_for_this_uri
 
     def __str__(self):
-        return u'<HTTPretty with %d URI entries>' % len(self._entries)
+        return '<HTTPretty with %d URI entries>' % len(self._entries)
 
     @classmethod
     def Response(cls, body, method=None, uri=None, adding_headers=None, forcing_headers=None,
                  status=200, streaming=False, **headers):
 
-        headers['body'] = body
-        headers['adding_headers'] = adding_headers
-        headers['forcing_headers'] = forcing_headers
-        headers['status'] = int(status)
-        headers['streaming'] = streaming
+        headers[str('body')] = body
+        headers[str('adding_headers')] = adding_headers
+        headers[str('forcing_headers')] = forcing_headers
+        headers[str('status')] = int(status)
+        headers[str('streaming')] = streaming
         return Entry(method, uri, **headers)
 
     @classmethod
@@ -707,7 +716,6 @@ class httpretty(HttpBaseClass):
         socket.gethostname = old_gethostname
         socket.gethostbyname = old_gethostbyname
         socket.getaddrinfo = old_getaddrinfo
-        socket.inet_aton = old_gethostbyname
 
         socket.__dict__['socket'] = old_socket
         socket.__dict__['_socketobject'] = old_socket
@@ -717,7 +725,6 @@ class httpretty(HttpBaseClass):
         socket.__dict__['gethostname'] = old_gethostname
         socket.__dict__['gethostbyname'] = old_gethostbyname
         socket.__dict__['getaddrinfo'] = old_getaddrinfo
-        socket.__dict__['inet_aton'] = old_gethostbyname
 
         if socks:
             socks.socksocket = old_socksocket
@@ -748,7 +755,6 @@ class httpretty(HttpBaseClass):
         socket.gethostname = fake_gethostname
         socket.gethostbyname = fake_gethostbyname
         socket.getaddrinfo = fake_getaddrinfo
-        socket.inet_aton = fake_gethostbyname
 
         socket.__dict__['socket'] = fakesock.socket
         socket.__dict__['_socketobject'] = fakesock.socket
@@ -757,7 +763,6 @@ class httpretty(HttpBaseClass):
         socket.__dict__['create_connection'] = create_fake_connection
         socket.__dict__['gethostname'] = fake_gethostname
         socket.__dict__['gethostbyname'] = fake_gethostbyname
-        socket.__dict__['inet_aton'] = fake_gethostbyname
         socket.__dict__['getaddrinfo'] = fake_getaddrinfo
 
         if socks:
